@@ -101,6 +101,9 @@ typedef enum {
   PANGO_UNDERLINE_ERROR
 } PangoUnderline;
 
+#define PANGO_ATTR_INDEX_FROM_TEXT_BEGINNING	0
+#define PANGO_ATTR_INDEX_TO_TEXT_END		G_MAXUINT
+
 struct _PangoAttribute
 {
   const PangoAttrClass *klass;
@@ -176,7 +179,8 @@ struct _PangoAttrFontDesc
   PangoFontDescription *desc;
 };
 
-PangoAttrType    pango_attr_type_register    (const gchar          *name);
+PangoAttrType         pango_attr_type_register (const gchar        *name);
+G_CONST_RETURN char * pango_attr_type_get_name (PangoAttrType       type) G_GNUC_CONST;
 
 void             pango_attribute_init        (PangoAttribute       *attr,
 					      const PangoAttrClass *klass);
